<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>SnapFree</name>
    <message>
        <location filename="../SnapFreeInit.js" line="+2"/>
        <source>&amp;Free</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Zablokuj wszystko
&amp;Odręczna linia</translatorcomment>
        <translation>&amp;Swobodnie</translation>
    </message>
</context>
</TS>
